@@ -88,6 +88,13 @@ class ConfigHelper:
         except ValueError:
             return False
 
+    def get_download_quizzes(self) -> bool:
+        # returns a stored boolean if quizzes should be downloaded
+        try:
+            return self.get_property('download_quizzes')
+        except ValueError:
+            return False
+
     def get_userid_and_version(self) -> (str, int):
         # returns the userid and a version
         try:
@@ -211,6 +218,11 @@ class ConfigHelper:
         except ValueError:
             options.update({'videopasswords': {}})
 
+        try:
+            options.update({'external_file_downloaders': self.get_property('external_file_downloaders')})
+        except ValueError:
+            options.update({'external_file_downloaders': {}})
+
         return options
 
     def get_restricted_filenames(self) -> {}:
